==> ktp-accounts-kcm-15.08.0.tar.xz: ktp-accounts-kcm-15.08.0/plugins/morse/ktpaccountskcm_plugin_morse.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Morse connection manager.
Comment[ast]=Interfaz d'usuariu de configuración de cuenta personalizada pa cuentes qu'usen el xestor de conexones Morse.
Comment[bs]=Korisnički interfejs konfiguratora prilagođenih korisničkih naloga koji koristi Morse menadžer konekcija.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Morse.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Morse.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Morse.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Morse-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Morse.
Comment[en_GB]=Custom account configuration user interface for accounts using the Morse connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Morse.
Comment[et]=Morse ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[fi]=Morse-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Morse ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Morse.
Comment[hu]=Egyedi beállítófelület a Morse kapcsolatkezelőt használó azonosítókhoz.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Morse.
Comment[ko]=Morse 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Morse tilkoblingsbehandler.
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Morse verbindingenbeheerder gebruiken.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Morse.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Morse.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Morse.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Morse.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью диспетчера соединений Morse.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Morse.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Morse.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Морзе.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Морзе.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Morse.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Morse.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Morse.
Comment[tr]=Morse bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü.
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями Morse.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Morse connection manager.xx
Comment[zh_CN]=通过 Morse 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Morse 連線管理員的帳號自訂帳號設定使用者介面。
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_morse
X-KDE-PluginInfo-Author=David Edmundson
X-KDE-PluginInfo-Email=kde@davidedmundson.co.uk
X-KDE-PluginInfo-Name=morse
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm_15.12.3.orig.tar.xz: ktp-accounts-kcm-15.12.3/plugins/morse/ktpaccountskcm_plugin_morse.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Morse connection manager.
Comment[ast]=Interfaz d'usuariu de configuración de cuenta personalizada pa cuentes qu'usen el xestor de conexones Morse.
Comment[bs]=Korisnički interfejs konfiguratora prilagođenih korisničkih naloga koji koristi Morse menadžer konekcija.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Morse.
Comment[ca@valencia]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Morse.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Morse.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Morse.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Morse-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Morse.
Comment[en_GB]=Custom account configuration user interface for accounts using the Morse connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Morse.
Comment[et]=Morse ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[fi]=Morse-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Morse ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Morse.
Comment[hu]=Egyedi beállítófelület a Morse kapcsolatkezelőt használó azonosítókhoz.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Morse.
Comment[ko]=Morse 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Morse tilkoblingsbehandler.
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Morse verbindingenbeheerder gebruiken.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Morse.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Morse.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Morse.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Morse.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью диспетчера соединений Morse.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Morse.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Morse.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Морзе.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Морзе.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Morse.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Morse.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Morse.
Comment[tr]=Morse bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü.
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями Morse.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Morse connection manager.xx
Comment[zh_CN]=通过 Morse 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Morse 連線管理員的帳號自訂帳號設定使用者介面。
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_morse
X-KDE-PluginInfo-Author=David Edmundson
X-KDE-PluginInfo-Email=kde@davidedmundson.co.uk
X-KDE-PluginInfo-Name=morse
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
